/*
 * DataManager database schema 200703
 */

CREATE SCHEMA sensor;
CREATE SCHEMA raw;
CREATE SCHEMA profile;
CREATE SCHEMA aggregation;
CREATE SCHEMA archivemanager;
CREATE SCHEMA admin;

CREATE TABLE conf (
name varchar PRIMARY KEY,
value varchar
);

CREATE TABLE status (
name varchar PRIMARY KEY,
value varchar
);

CREATE TABLE slaveReplicationProfile (
replicationType name PRIMARY KEY,
done timestamptz NOT NULL
);

CREATE TABLE sensor.combined (
id varchar PRIMARY KEY,
passwd varchar NOT NULL,
working boolean,
ownerName varchar,
ownerMailAddress varchar
);

CREATE TABLE sensor.element (
id varchar PRIMARY KEY,
combined_id varchar REFERENCES sensor.combined (id) NOT NULL,
working boolean
);

/*
 * CREATE TABLE profile.schema (
 * name varchar PRIMARY KEY,
 * type varchar NOT NULL,
 * class varchar NOT NULL,
 * value varchar,
 * multilanguage boolean,
 * description varchar,
 * visibility varchar
 * );
 * 
 * CREATE TABLE profile.locale (
 * name varchar PRIMARY KEY,
 * language_code varchar NOT NULL
 * );
 */
 
CREATE TABLE profile.combined_archive (
id varchar REFERENCES sensor.combined (id),
created timestamptz,
expired timestamptz,
latitude float8,
longitude float8,
attrs varchar,
PRIMARY KEY(id,created)
);

CREATE VIEW profile.combined AS 
	SELECT * FROM profile.combined_archive 
	WHERE expired IS NULL;


CREATE TABLE profile.element_archive (
id varchar REFERENCES sensor.element (id),
created timestamptz,
expired timestamptz,
sensorType varchar,
attrs varchar,
PRIMARY KEY(id,created)
);

CREATE VIEW profile.element AS
	SELECT * FROM profile.element_archive
	WHERE expired IS NULL;

CREATE TABLE raw.latest (
id varchar REFERENCES sensor.element(id) PRIMARY KEY,
time timestamptz NOT NULL,
attrs varchar,
value float8,
sValue varchar
);


CREATE TABLE raw.archive (
id varchar REFERENCES sensor.element (id),
time timestamptz,
attrs varchar,
value float8,
sValue varchar,
PRIMARY KEY(id,time)
);
 
 
CREATE TABLE aggregation.work (
id varchar REFERENCES sensor.element (id),
time timestamptz,
attrs varchar,
value float8,
sValue varchar,
PRIMARY KEY(id,time)
);

CREATE TABLE aggregation.profile (
scope varchar PRIMARY KEY,
done timestamptz NOT NULL
);

CREATE TABLE aggregation.hour (
id varchar REFERENCES sensor.element (id),
aggregationType varchar,
time timestamptz,
attrs varchar,
value float8,
sValue varchar,
PRIMARY KEY(id,aggregationType,time)
);

CREATE TABLE aggregation.day (
id varchar REFERENCES sensor.element (id),
aggregationType varchar,
time timestamptz,
attrs varchar,
value float8,
sValue varchar,
PRIMARY KEY(id,aggregationType,time)
);

CREATE TABLE aggregation.month (
id varchar REFERENCES sensor.element (id),
aggregationType varchar,
time timestamptz,
attrs varchar,
value float8,
sValue varchar,
PRIMARY KEY(id,aggregationType,time)
);

/*
 * CREATE TABLE archivemanager.conf (
 * id varchar PRIMARY KEY
 * );
 *
 * CREATE TABLE archivemanager.status (
 * id varchar PRIMARY KEY
 * );
 *
 * CREATE TABLE archivemanager.server (
 * id varchar PRIMARY KEY
 * );
 */

/*
 * admin.conf
 *  |  name  |  value     |
 *  +--------+------------+
 *  |  site  |    name    |
 */
CREATE TABLE admin.conf (
name varchar PRIMARY KEY,
value varchar
);

CREATE TABLE admin.neighbor (
name varchar PRIMARY KEY,
type varchar NOT NULL,
server varchar NOT NULL
);

CREATE TABLE admin.schema (
name varchar PRIMARY KEY,
type varchar NOT NULL,
class varchar NOT NULL,
value varchar,
multilanguage boolean,
description varchar,
visibility varchar,
delegate varchar
);

CREATE TABLE admin.locale (
name varchar PRIMARY KEY,
language_code varchar NOT NULL
);

CREATE TABLE admin.combined (
id varchar PRIMARY KEY,
site varchar REFERENCES admin.neighbor(name) ON DELETE CASCADE,
updated timestamptz
);

CREATE TABLE admin.element (
id varchar PRIMARY KEY,
combined_id varchar REFERENCES admin.combined(id) ON DELETE CASCADE
);

CREATE TABLE admin.combined_index (
id varchar REFERENCES admin.combined(id) ON DELETE CASCADE,
name varchar NOT NULL,
sValue varchar,
fValue float8,
iValue integer,
tValue timestamptz,
PRIMARY KEY(id,name)
);

CREATE TABLE admin.element_index (
id varchar REFERENCES admin.element(id) ON DELETE CASCADE,
name varchar NOT NULL,
sValue varchar,
fValue float8,
iValue integer,
tValue timestamptz,
PRIMARY KEY(id,name)
);
